==> advanced-systemui_0.5.5.tar.gz: advanced-systemui-0.5.5/dbus.h <==
#include <dbus/dbus.h>

typedef enum {
  // GTK returns this if a response widget has no response_id,
  // or if the dialog gets programmatically hidden or destroyed.
  GTK_RESPONSE_NONE = -1,

  // GTK won't return these unless you pass them in
  // as the response for an action widget. They are
  // for your convenience.
  GTK_RESPONSE_REJECT = -2,
  GTK_RESPONSE_ACCEPT = -3,

  // If the dialog is deleted.
  GTK_RESPONSE_DELETE_EVENT = -4,

  // These are returned from GTK dialogs, and you can also use them
  // yourself if you like.
  GTK_RESPONSE_OK     = -5,
  GTK_RESPONSE_CANCEL = -6,
  GTK_RESPONSE_CLOSE  = -7,
  GTK_RESPONSE_YES    = -8,
  GTK_RESPONSE_NO     = -9,
  GTK_RESPONSE_APPLY  = -10,
  GTK_RESPONSE_HELP   = -11
} GtkResponseType;

#define _STRING_ DBUS_TYPE_STRING
#define _BOOL_ DBUS_TYPE_BOOLEAN
#define _UINT32_ DBUS_TYPE_UINT32
#define _INT32_ DBUS_TYPE_INT32
#define _DOUBLE_ DBUS_TYPE_DOUBLE
#define _ARRAY_ DBUS_TYPE_ARRAY
//#define _VARIANT_ DBUS_TYPE_VARIANT
#define _END_ DBUS_TYPE_INVALID

extern DBusError dbus_error;
extern unsigned dbus_listening;

extern unsigned original_screen_autolock, original_screen_stayslit;

//////////////////////////////////////////////////////////////////////////

extern int dbus_wakeup_fd;

#define _WAKEUP_SHOW_ (char)1
#define _WAKEUP_HIDE_ (char)2
#define _WAKEUP_ROTATE_LEFT_ (char)3
#define _WAKEUP_ROTATE_RIGHT_ (char)4
#define _WAKEUP_LOCK_BUTTON_ (char)5
#define _WAKEUP_DEVICE_LOCK_ (char)6
#define _WAKEUP_REFRESH_ (char)7
#define _WAKEUP_SHUTDOWN_ (char)8

//////////////////////////////////////////////////////////////////////////

int dbus_init( );
void dbus_send_wakeup( char message );
void dbus_disconnect( );

#ifdef ARCH_armel
void dbus_send_method( const char *destination, const char *path, const char *interface, const char *method, int first_arg_type, ... );
void dbus_send_reply( DBusConnection *bus, DBusMessage *method_call, int first_arg_type, ... );
void dbus_send_signal( const char *path, const char *interface, const char *signal, int first_arg_type, ... );

void dbus_recv_method( DBusPendingCallNotifyFunction callback, const char *destination, const char *path, const char *interface, const char *method, int first_arg_type, ... );
void dbus_flush_messages( );

void dbus_send_session_method( const char *destination, const char *path, const char *interface, const char *method, int first_arg_type, ... );
#endif

void notify_screen_locked( );
void notify_screen_unlocked( );
void notify_power_unlock_key( );
void notify_blanking_pause1( );
void notify_blanking_pause2( );

void dbus_send_charging_status_signal( );
void dbus_send_battery_capacity_signal( );

==> advanced-systemui_0.5.6.tar.gz: advanced-systemui-0.5.6/dbus.h <==
#include <dbus/dbus.h>

typedef enum {
  // GTK returns this if a response widget has no response_id,
  // or if the dialog gets programmatically hidden or destroyed.
  GTK_RESPONSE_NONE = -1,

  // GTK won't return these unless you pass them in
  // as the response for an action widget. They are
  // for your convenience.
  GTK_RESPONSE_REJECT = -2,
  GTK_RESPONSE_ACCEPT = -3,

  // If the dialog is deleted.
  GTK_RESPONSE_DELETE_EVENT = -4,

  // These are returned from GTK dialogs, and you can also use them
  // yourself if you like.
  GTK_RESPONSE_OK     = -5,
  GTK_RESPONSE_CANCEL = -6,
  GTK_RESPONSE_CLOSE  = -7,
  GTK_RESPONSE_YES    = -8,
  GTK_RESPONSE_NO     = -9,
  GTK_RESPONSE_APPLY  = -10,
  GTK_RESPONSE_HELP   = -11
} GtkResponseType;

#define _STRING_ DBUS_TYPE_STRING
#define _BOOL_ DBUS_TYPE_BOOLEAN
#define _UINT32_ DBUS_TYPE_UINT32
#define _INT32_ DBUS_TYPE_INT32
#define _DOUBLE_ DBUS_TYPE_DOUBLE
#define _ARRAY_ DBUS_TYPE_ARRAY
//#define _VARIANT_ DBUS_TYPE_VARIANT
#define _END_ DBUS_TYPE_INVALID

extern DBusError dbus_error;
extern unsigned dbus_listening;

extern unsigned original_screen_autolock, original_screen_stayslit;

//////////////////////////////////////////////////////////////////////////

extern int dbus_wakeup_fd;

#define _WAKEUP_SHOW_ (char)1
#define _WAKEUP_HIDE_ (char)2
#define _WAKEUP_ROTATE_LEFT_ (char)3
#define _WAKEUP_ROTATE_RIGHT_ (char)4
#define _WAKEUP_LOCK_BUTTON_ (char)5
#define _WAKEUP_DEVICE_LOCK_ (char)6
#define _WAKEUP_REFRESH_ (char)7
#define _WAKEUP_SHUTDOWN_ (char)8

//////////////////////////////////////////////////////////////////////////

int dbus_init( );
void dbus_send_wakeup( char message );
void dbus_disconnect( );

#ifdef ARCH_armel
void dbus_send_method( const char *destination, const char *path, const char *interface, const char *method, int first_arg_type, ... );
void dbus_send_reply( DBusConnection *bus, DBusMessage *method_call, int first_arg_type, ... );
void dbus_send_signal( const char *path, const char *interface, const char *signal, int first_arg_type, ... );

void dbus_recv_method( DBusPendingCallNotifyFunction callback, const char *destination, const char *path, const char *interface, const char *method, int first_arg_type, ... );
void dbus_flush_messages( );

void dbus_send_session_method( const char *destination, const char *path, const char *interface, const char *method, int first_arg_type, ... );
#endif

void notify_screen_locked( );
void notify_screen_unlocked( );
void notify_power_unlock_key( );
void notify_blanking_pause1( );
void notify_blanking_pause2( );

void dbus_send_charging_status_signal( );
void dbus_send_battery_capacity_signal( );

#define is_value_visible(widget_page) (window.is_mapped && current_dialog_draw == NULL && primary_widgets == widget_page)
